(ns rlm.rlm-commands
  (:require  [rlm ns-rlm shell-write]
	     [clojure.contrib [duck-streams :as ds]])
  (:use [clojure.contrib java-utils])
  (:use clojure.java.javadoc))


(defn current-directory [] (ds/file-str "/home/r/mobius"))

(defn file-re [regex & {:keys [dir recurse] :or
			{dir (current-directory) recurse false}}]
  (let [dir (ds/file-str dir)]
    (filter (fn [file] (re-matches regex (.getName file)))
	    (if recurse
	      (file-seq dir)
	      (seq (.listFiles dir))))))

(defmacro undef
  "removes symbol from the current namespace"
  [& symbols]
 
  `(dorun (map (partial ns-unmap *ns*) (quote ~symbols))))


(defn ns-reset-fn
  "unmaps all interned symbols from the current namespace (except in-ns and ns)"
  ([ns-name]
     (map (fn [s] (ns-unmap ns-name s))
	  (keys (ns-interns ns-name)))))

(defmacro ns-reset
  "unmaps all symbols from the current namespace (except in-ns and ns)"
  ([ns-name] `(ns-clear-fn (quote ~ns-name)))
  ([] `(ns-clear-fn (quote ~(symbol (str *ns*))))))

(defmacro ns-nuke-old
  ([]
     (let [current-ns# (symbol (str *ns*))]
       `(do 
	  (println "NUKING namespace" (quote ~current-ns#))
	  (clojure.lang.Namespace/remove  (quote ~current-ns#))
	  (ns ~current-ns#)))))

(defmacro ns-nuke
  "Removes all symbols and all referenced symbols. Use as a last
   resort."
  ([]
     (let [current-ns# (symbol (str *ns*))]
       `(ns-nuke ~current-ns#)))
  ([ns]
     `(do
	(println "NUKING namespace" (quote ~ns))
	(clojure.lang.Namespace/remove  (quote ~ns))
	(ns ~ns))))

(defmacro reload []
  `(do
     (rlm.ns-rlm/ns-clear)
     (use :reload-all (quote ~(symbol (str *ns*))))))

(defmacro reload []
  `(do
     (rlm.rlm-commands/ns-nuke)
     (clojure.core/use
      :reload-all
      (clojure.core/symbol (clojure.core/str clojure.core/*ns*)))))

(defmacro re "faster"
  []
  `(do
     (rlm.rlm-commands/ns-nuke)
     (clojure.core/use :reload
      (clojure.core/symbol (clojure.core/str clojure.core/*ns*)))))

(defn keymap-clojure []
  (rlm.shell-write/sw "xmodmap" "/home/r/.xmodmap.clojure"))



(defn keymap-normal []
  (rlm.shell-write/sw "xmodmap" "/home/r/.xmodmap.normal"))


(defn rlm []
  (clojure.core/require 'rlm.light-base)
  (rlm.ns-rlm/ns-clone rlm.light-base))


(defn help
  "load a bunch of really useful help functions"
  []
  (use
   '[rlm
     [function-utils :only [mix defmix runonce]]
     [rlm-commands :only [undef ns-reset ns-nuke reload keymap-clojure keymap-normal rlm]]
     [ns-rlm :only [ns-clear ns-clone ls]]
     [play-all :only [play-all-music]]
     [shell-inspect :only [command-line?]]
     [shell-write :only [sw]]
     [classpath-utils :only [classpath add-to-classpath]]
     [dreams :only [megadef silence]]
     [map-utils :only [map-keys map-vals filter-keys filter-vals]]
     [visualize :only [visual]]
     [identify :only [identify]]]
   '[abomination.no-parens :only [quit]]
   
   
   '[clojure.contrib
     [duck-streams :only [file-str read-lines]]
     [str-utils :only [re-split re-gsub str-join]]
     [repl-utils :only [show expression-info]]]
    '[clojure
      [repl :only [source]]]
     '[clojure.java
       [javadoc :only [javadoc add-local-javadoc]]])
  (clojure.java.javadoc/add-local-javadoc "/home/r/cortex/jme3/dist/javadoc")
  (clojure.java.javadoc/add-local-javadoc "/home/r/roBin/jdk6-docs/docs/api")
  (clojure.java.javadoc/add-local-javadoc 
   "/home/r/roBin/lpsolve-doc/lpsolve.sourceforge.net/5.5/Java/docs/api")
  (clojure.java.javadoc/add-local-javadoc 
   "/home/r/roBin/lpsolve-doc/lpsolve.sourceforge.net/5.5/Java/docs/api")
  
  nil)

 

